@@ -3,7 +3,7 @@
 import random
 import sys
 from dataclasses import dataclass, field
-from typing import Dict, List, Optional, Set
+from typing import Any, Dict, List, Optional, Set
 
 from dataclasses_json import DataClassJsonMixin
 
@@ -51,6 +51,9 @@ class Node(IndexStruct):
     # reference document id
     ref_doc_id: Optional[str] = None
 
+    # extra node info
+    node_info: Optional[Dict[str, Any]] = None
+
     def get_text(self) -> str:
         """Get text."""
         text = super().get_text()
@@ -248,3 +251,12 @@ class WeaviateIndexStruct(IndexStruct):
         if self.class_prefix is None:
             raise ValueError("class_prefix must be provided.")
         return self.class_prefix
+
+
+@dataclass
+class PineconeIndexStruct(IndexStruct):
+    """An index struct for Pinecone.
+
+    Docs are stored in Pinecone directly.
+
+    """
