@@ -9,6 +9,7 @@ from gpt_index.data_structs.data_structs import IndexStruct, Node
 from gpt_index.embeddings.base import BaseEmbedding
 from gpt_index.embeddings.openai import OpenAIEmbedding
 from gpt_index.indices.prompt_helper import PromptHelper
+from gpt_index.indices.query.embedding_utils import SimilarityTracker
 from gpt_index.indices.response.builder import (
     ResponseBuilder,
     ResponseMode,
@@ -64,6 +65,8 @@ class BaseGPTIndexQuery(Generic[IS]):
         include_summary (bool): Optional bool. If True, will also use the summary
             text of the index when generating a response (the summary text can be set
             through `index.set_text("<text>")`).
+        similarity_cutoff (float): Optional float. If set, will filter out nodes with
+            similarity below this cutoff threshold when computing the response
 
     """
 
@@ -83,6 +86,7 @@ class BaseGPTIndexQuery(Generic[IS]):
         refine_template: Optional[RefinePrompt] = None,
         include_summary: bool = False,
         response_kwargs: Optional[Dict] = None,
+        similarity_cutoff: Optional[float] = None,
     ) -> None:
         """Initialize with parameters."""
         if index_struct is None:
@@ -115,7 +119,11 @@ class BaseGPTIndexQuery(Generic[IS]):
             self.refine_template,
         )
 
-    def _should_use_node(self, node: Node) -> bool:
+        self.similarity_cutoff = similarity_cutoff
+
+    def _should_use_node(
+        self, node: Node, similarity_tracker: Optional[SimilarityTracker] = None
+    ) -> bool:
         """Run node through filters to determine if it should be used."""
         words = re.findall(r"\w+", node.get_text())
         if self._required_keywords is not None:
@@ -128,6 +136,17 @@ class BaseGPTIndexQuery(Generic[IS]):
                 if w in words:
                     return False
 
+        sim_cutoff_exists = (
+            similarity_tracker is not None and self.similarity_cutoff is not None
+        )
+
+        if sim_cutoff_exists:
+            similarity = cast(SimilarityTracker, similarity_tracker).find(node)
+            if similarity is None:
+                return False
+            if cast(float, similarity) < cast(float, self.similarity_cutoff):
+                return False
+
         return True
 
     def _get_text_from_node(
@@ -194,31 +213,48 @@ class BaseGPTIndexQuery(Generic[IS]):
 
         return response or ""
 
-    def get_nodes_for_response(
+    def get_nodes_and_similarities_for_response(
         self, query_str: str, verbose: bool = False
-    ) -> List[Node]:
-        """Get nodes for response."""
-        nodes = self._get_nodes_for_response(query_str, verbose=verbose)
-        nodes = [node for node in nodes if self._should_use_node(node)]
+    ) -> List[Tuple[Node, Optional[float]]]:
+        """Get list of tuples of node and similarity for response.
+
+        First part of the tuple is the node.
+        Second part of tuple is the distance from query to the node.
+        If not applicable, it's None.
+        """
+        similarity_tracker = SimilarityTracker()
+        nodes = self._get_nodes_for_response(
+            query_str, similarity_tracker=similarity_tracker, verbose=verbose
+        )
+        nodes = [
+            node for node in nodes if self._should_use_node(node, similarity_tracker)
+        ]
+
         # TODO: create a `display` method to allow subclasses to print the Node
-        return nodes
+        return similarity_tracker.get_zipped_nodes(nodes)
 
     @abstractmethod
     def _get_nodes_for_response(
-        self, query_str: str, verbose: bool = False
+        self,
+        query_str: str,
+        verbose: bool = False,
+        similarity_tracker: Optional[SimilarityTracker] = None,
     ) -> List[Node]:
         """Get nodes for response."""
 
     def _query(self, query_str: str, verbose: bool = False) -> Response:
         """Answer a query."""
         # TODO: remove _query and just use query
-        nodes = self.get_nodes_for_response(query_str, verbose=verbose)
+        tuples = self.get_nodes_and_similarities_for_response(
+            query_str, verbose=verbose
+        )
         source_builder = ResponseSourceBuilder()
         node_texts = []
-        for node in nodes:
+        for node, similarity in tuples:
             text, response = self._get_text_from_node(query_str, node, verbose=verbose)
-            source_builder.add_node(node)
+            source_builder.add_node(node, similarity=similarity)
             if response is not None:
+                # these are source nodes from within this node (when it's an index)
                 for source_node in response.source_nodes:
                     source_builder.add_source_node(source_node)
             node_texts.append(text)
