@@ -14,7 +14,7 @@ from gpt_index.readers.discord_reader import DiscordReader
 from gpt_index.readers.faiss import FaissReader
 
 # readers
-from gpt_index.readers.file import SimpleDirectoryReader
+from gpt_index.readers.file.base import SimpleDirectoryReader
 from gpt_index.readers.google.gdocs import GoogleDocsReader
 from gpt_index.readers.make_com.wrapper import MakeWrapper
 from gpt_index.readers.mongo import SimpleMongoReader
@@ -24,11 +24,17 @@ from gpt_index.readers.schema.base import Document
 from gpt_index.readers.slack import SlackReader
 from gpt_index.readers.string_iterable import StringIterableReader
 from gpt_index.readers.weaviate.reader import WeaviateReader
-from gpt_index.readers.web import SimpleWebPageReader, TrafilaturaWebReader
+from gpt_index.readers.web import (
+    BeautifulSoupWebReader,
+    SimpleWebPageReader,
+    TrafilaturaWebReader,
+)
 from gpt_index.readers.wikipedia import WikipediaReader
+from gpt_index.readers.youtube_transcript import YoutubeTranscriptReader
 
 __all__ = [
     "WikipediaReader",
+    "YoutubeTranscriptReader",
     "SimpleDirectoryReader",
     "SimpleMongoReader",
     "NotionPageReader",
@@ -41,6 +47,7 @@ __all__ = [
     "Document",
     "StringIterableReader",
     "SimpleWebPageReader",
+    "BeautifulSoupWebReader",
     "TrafilaturaWebReader",
     "MakeWrapper",
 ]
