@@ -1,7 +1,7 @@
 """Base schema for data structures."""
 from abc import ABC
 from dataclasses import dataclass, field
-from typing import Dict, List, Optional
+from typing import Any, Dict, List, Optional
 
 from dataclasses_json import DataClassJsonMixin
 
@@ -22,6 +22,9 @@ class BaseDocument(ABC):
     doc_id: Optional[str] = None
     embedding: Optional[List[float]] = None
 
+    # extra fields
+    extra_info: Optional[Dict[str, Any]] = None
+
     def get_text(self) -> str:
         """Get text."""
         if self.text is None:
